summaryrefslogtreecommitdiffstats
path: root/tdeioslave/file/file.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 14:20:53 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 14:20:53 -0600
commite3379a9953ab5532065dbe90bdb5a5fe14565641 (patch)
tree744fa731d7349b3ac60ad82f2f56605a19b86b0c /tdeioslave/file/file.cc
parenta3e01ba75c1f4886f3d2f2abeeb2715f39957974 (diff)
downloadtdelibs-e3379a9953ab5532065dbe90bdb5a5fe14565641.tar.gz
tdelibs-e3379a9953ab5532065dbe90bdb5a5fe14565641.zip
Rename additional kioslave libraries
Diffstat (limited to 'tdeioslave/file/file.cc')
-rw-r--r--tdeioslave/file/file.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdeioslave/file/file.cc b/tdeioslave/file/file.cc
index 499a69330..c8112c3b5 100644
--- a/tdeioslave/file/file.cc
+++ b/tdeioslave/file/file.cc
@@ -113,14 +113,14 @@ extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
int kdemain( int argc, char **argv )
{
KLocale::setMainCatalogue("tdelibs");
- TDEInstance instance( "kio_file" );
+ TDEInstance instance( "tdeio_file" );
( void ) TDEGlobal::locale();
kdDebug(7101) << "Starting " << getpid() << endl;
if (argc != 4)
{
- fprintf(stderr, "Usage: kio_file protocol domain-socket1 domain-socket2\n");
+ fprintf(stderr, "Usage: tdeio_file protocol domain-socket1 domain-socket2\n");
exit(-1);
}
@@ -998,7 +998,7 @@ bool FileProtocol::createUDSEntry( const TQString & filename, const TQCString &
{
assert(entry.count() == 0); // by contract :-)
// Note: details = 0 (only "file or directory or symlink or doesn't exist") isn't implemented
// because there's no real performance penalty in kio_file for returning the complete
// details. Please consider doing it in your tdeioslave if you're using this one as a model :)
UDSAtom atom;
atom.m_uds = TDEIO::UDS_NAME;
@@ -998,7 +998,7 @@ bool FileProtocol::createUDSEntry( const TQString & filename, const TQCString &
assert(entry.count() == 0); // by contract :-)
// Note: details = 0 (only "file or directory or symlink or doesn't exist") isn't implemented
- // because there's no real performance penalty in kio_file for returning the complete
+ // because there's no real performance penalty in tdeio_file for returning the complete
// details. Please consider doing it in your tdeioslave if you're using this one as a model :)
UDSAtom atom;